==> geometric_calibration-0.1.1.tar.gz: geometric_calibration-0.1.1/setup.py <==
#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open("README.rst") as readme_file:
    readme = readme_file.read()

with open("HISTORY.rst") as history_file:
    history = history_file.read()

requirements = ["Click>=7.0", "matplotlib", "numpy", "scipy"]

setup_requirements = [
    "pytest-runner",
]

test_requirements = [
    "pytest>=3",
]

setup(
    author="Matteo Rossi",
    author_email="rossimatteo1993@gmail.com",
    python_requires=">=3.6",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    description="A utility to perform Geometric Calibration of a C-Arm Structure mounted on a robotic system",
    entry_points={
        "console_scripts": [
            "geometric_calibration=geometric_calibration.cli:main",
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + "\n\n" + history,
    include_package_data=True,
    keywords="geometric_calibration",
    name="geometric_calibration",
    packages=find_packages(
        include=["geometric_calibration", "geometric_calibration.*"]
    ),
    setup_requires=setup_requirements,
    test_suite="tests",
    tests_require=test_requirements,
    url="https://github.com/mrossi93/geometric_calibration",
    version="0.1.1",
    zip_safe=False,
)

==> geometric_calibration-0.1.2.tar.gz: geometric_calibration-0.1.2/setup.py <==
#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open("README.rst") as readme_file:
    readme = readme_file.read()

with open("HISTORY.rst") as history_file:
    history = history_file.read()

requirements = ["Click>=7.0", "matplotlib", "numpy", "scipy", "colorama"]

setup_requirements = [
    "pytest-runner",
]

test_requirements = [
    "pytest>=3",
]

setup(
    author="Matteo Rossi",
    author_email="rossimatteo1993@gmail.com",
    python_requires=">=3.6",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    description="A utility to perform Geometric Calibration of a C-Arm Structure mounted on a robotic system",
    entry_points={
        "console_scripts": [
            "geometric_calibration=geometric_calibration.cli:main",
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + "\n\n" + history,
    include_package_data=True,
    keywords="geometric_calibration",
    name="geometric_calibration",
    packages=find_packages(
        include=["geometric_calibration", "geometric_calibration.*"]
    ),
    setup_requires=setup_requirements,
    test_suite="tests",
    tests_require=test_requirements,
    url="https://github.com/mrossi93/geometric_calibration",
    version="0.1.2",
    zip_safe=False,
)
